@@ -12,4 +12,4 @@ def update_project(project_list):
             os.chdir('../')
         except Exception as error:
             print(error)
-    print(datetime.now(), f':: build {len(project_list)} project(s)')
+    print(datetime.now(), f':: pulled {len(project_list)} project(s)')
