@@ -13,4 +13,4 @@ def update_to_git(project_list):
             os.chdir('../')
         except Exception as error:
             print(error)
-    print(datetime.now(), f':: build {len(project_list)} project(s)')
+    print(datetime.now(), f':: pushed {len(project_list)} project(s)')
